ErrorCause

Enum ErrorCause 

#[non_exhaustive]
pub enum ErrorCause { CommandSubstError(Errno), ArithError(ArithError), AssignReadOnly(AssignReadOnlyError), UnsetParameter { param: Param, }, VacantExpansion(VacantError), NonassignableParameter(NonassignableError), Interrupted(ExitStatus), }
Types of errors that may occur in the word expansion.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


CommandSubstError(Errno)

System error while performing a command substitution.



ArithError(ArithError)

Error while evaluating an arithmetic expansion.



AssignReadOnly(AssignReadOnlyError)

Assignment to a read-only variable.



UnsetParameter

Expansion of an unset parameter with the nounset option

Fields

param: Param


VacantExpansion(VacantError)

Expansion of an empty value with an error switch



NonassignableParameter(NonassignableError)

Assignment to a nonassignable parameter



Interrupted(ExitStatus)

Expansion interrupted by SIGINT in an interactive shell

This variant is used to propagate a SIGINT interruption that occurred during word expansion (e.g., in a command substitution or pathname expansion). The exit status is derived from the SIGINT signal.

Implementations

Source

impl ErrorCause

pub fn message(&self) -> &str

Returns an error message describing the error.

pub fn label(&self) -> Cow<'_, str>

Returns a label for annotating the error location.

pub fn related_location(&self) -> Option<(&Location, &'static str)>

Returns a location related with the error cause and a message describing the location.

pub fn footer(&self) -> Option<&'static str>

Returns a footer message for the error.