#[non_exhaustive]pub enum ArithError {
Show 16 variants
InvalidNumericConstant,
InvalidCharacter,
IncompleteExpression,
MissingOperator,
UnclosedParenthesis {
opening_location: Location,
},
QuestionWithoutColon {
question_location: Location,
},
ColonWithoutQuestion,
InvalidOperator,
NonPortableIncrementDecrement,
InvalidVariableValue(String),
Overflow,
DivisionByZero,
LeftShiftingNegative,
ReverseShifting,
AssignmentToValue,
Unrecognized(String),
}Expand description
Types of errors that may occur in arithmetic expansion
This enum is essentially equivalent to yash_arith::ErrorCause. The
differences between the two are:
ArithErrordefines all error variants flatly whileErrorCausehas nested variants.ArithErrormay contain informativeLocationthat can be used to produce an error message with annotated code whileErrorCausemay just specify a location as an index range.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidNumericConstant
A value token contains an invalid character.
InvalidCharacter
An expression contains a character that is not a whitespace, number, or number.
IncompleteExpression
Expression with a missing value
MissingOperator
Operator missing
UnclosedParenthesis
( without )
QuestionWithoutColon
? without :
ColonWithoutQuestion
: without ?
InvalidOperator
Other error in operator usage
NonPortableIncrementDecrement
An increment or decrement operator is used while the portable option
is on.
InvalidVariableValue(String)
A variable value that is not a valid number
Overflow
Result out of bounds
DivisionByZero
Division by zero
LeftShiftingNegative
Left bit-shifting of a negative value
ReverseShifting
Bit-shifting with a negative right-hand-side operand
AssignmentToValue
Assignment with a left-hand-side operand not being a variable
Unrecognized(String)
An arithmetic error not recognized by this crate
This variant is used to wrap an error cause that is returned by future
versions of yash_arith but not yet recognized by this crate. The
associated string is the Display representation of the error cause.
Implementations
Sourceimpl ArithError
impl ArithError
Returns a location related with this error and a message describing the location.