#[non_exhaustive]pub enum ErrorCause {
Expansion(ErrorCause),
NulByte(NulError),
FdNotOverwritten(Fd, Errno),
ReservedFd(Fd),
OpenFile(CString, Errno),
MalformedFd(String, ParseIntError),
UnreadableFd(Fd),
UnwritableFd(Fd),
TemporaryFileUnavailable(Errno),
UnsupportedPipeRedirection,
UnsupportedHereString,
}Expand description
Types of errors that may occur in the redirection.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Expansion(ErrorCause)
Expansion error.
NulByte(NulError)
Pathname containing a nul byte.
FdNotOverwritten(Fd, Errno)
The target file descriptor could not be modified for the redirection.
ReservedFd(Fd)
Use of an FD reserved by the shell
This error occurs when a redirection tries to modify an existing FD with the CLOEXEC flag set. See the module documentation for details.
OpenFile(CString, Errno)
Error while opening a file.
The CString is the pathname of the file that could not be opened.
MalformedFd(String, ParseIntError)
Operand of <& or >& that cannot be parsed as an integer.
UnreadableFd(Fd)
<& applied to an unreadable file descriptor
UnwritableFd(Fd)
>& applied to an unwritable file descriptor
Error preparing a temporary file to save here-document content
UnsupportedPipeRedirection
Pipe redirection is used, which is not yet implemented.
UnsupportedHereString
Here-string redirection is used, which is not yet implemented.
Implementations