ArithError

Enum ArithError 

pub enum ArithError {
Show 14 variants InvalidNumericConstant, InvalidCharacter, IncompleteExpression, MissingOperator, UnclosedParenthesis { opening_location: Location, }, QuestionWithoutColon { question_location: Location, }, ColonWithoutQuestion, InvalidOperator, InvalidVariableValue(String), Overflow, DivisionByZero, LeftShiftingNegative, ReverseShifting, AssignmentToValue,
}
Types of errors that may occur in arithmetic expansion

This enum is essentially equivalent to yash_arith::ErrorCause. The differences between the two are:

  • ArithError defines all error variants flatly while ErrorCause has nested variants.
  • ArithError may contain informative Location that can be used to produce an error message with annotated code while ErrorCause may just specify a location as an index range.

Variants



InvalidNumericConstant

A value token contains an invalid character.



InvalidCharacter

An expression contains a character that is not a whitespace, number, or number.



IncompleteExpression

Expression with a missing value



MissingOperator

Operator missing



UnclosedParenthesis

( without )

Fields

opening_location: Location


QuestionWithoutColon

? without :

Fields

question_location: Location


ColonWithoutQuestion

: without ?



InvalidOperator

Other error in operator usage



InvalidVariableValue(String)

A variable value that is not a valid number



Overflow

Result out of bounds



DivisionByZero

Division by zero



LeftShiftingNegative

Left bit-shifting of a negative value



ReverseShifting

Bit-shifting with a negative right-hand-side operand



AssignmentToValue

Assignment with a left-hand-side operand not being a variable

Implementations

Source

impl ArithError

pub fn related_location(&self) -> Option<(&Location, &'static str)>

Returns a location related with this error and a message describing the location.